--------------------------------------------------------------------------------
-- Weapon HAX
-- made by mat5b and Peter S. a.k.a. DarkCorner
-- October 2009, www.tf2d.proboards.com
--------------------------------------------------------------------------------

-- Setup Tables
if cc==nil then cc={} end
cc.HAX={}
cc.HAX.grenade={}

-- Load & Prepare Ressources
cc.HAX.gfx_wpn=loadgfx("weapons/push.bmp")
setmidhandle(cc.HAX.gfx_wpn)
cc.HAX.sfx_attack=loadsfx("HAX.ogg")
cc.HAX.grenade.gfx_wpn=loadgfx("computer.png")

--------------------------------------------------------------------------------
-- Weapon: HAX
--------------------------------------------------------------------------------

cc.HAX.id=addweapon("cc.HAX","HAX",cc.HAX.grenade.gfx_wpn)

function cc.HAX.draw()	
	-- Decrease Timer (used for arm animation)
	if weapon_timer>0.0 then
		weapon_timer=weapon_timer-0.5
	end
	-- Draw
	if getplayeraction(0)==0 then
		setblend(blend_alpha)
		setalpha(1)
		setcolor(255,255,255)
		setscale(-getplayerdirection(0),1)
		setrotation(0)
		drawimage(cc.HAX.gfx_wpn,getplayerx(0)+getplayerdirection(0)*(7+weapon_timer),getplayery(0)+5)
	end
	if weapon_shots==0 then
		hudcrosshair(5,2)
	end
end

function cc.HAX.attack(attack)
	if (weapon_shots<=0) then
		if (attack==1) then
			-- No more weapon switching!
			useweapon(0)
			playsound(cc.HAX.sfx_attack)
			weapon_shots=weapon_shots+1
			-- Set timer for arm animation
			weapon_timer=5
			id=createprojectile(cc.HAX.grenade.id)
			projectiles[id]={}
			-- Ignore collision with current player at beginning
			projectiles[id].ignore=playercurrent()
			-- Set initial position of projectile
			projectiles[id].x=getplayerx(0)+(4*getplayerdirection(0))+math.sin(math.rad(getplayerrotation(0)))*10.0
			projectiles[id].y=getplayery(0)+3-math.cos(math.rad(getplayerrotation(0)))*10.0
			-- Set speed of projectile
			projectiles[id].sx=math.sin(math.rad(getplayerrotation(0)))*10.0
			projectiles[id].sy=-math.cos(math.rad(getplayerrotation(0)))*10.0
			-- Set timer
			projectiles[id].timer=3*40
			-- Effects
			recoil(2)
			-- End Turn
			endturn()
		end
	end
end

cc.HAX.grenade.id=addprojectile("cc.HAX.grenade")

function cc.HAX.grenade.draw(id)
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	-- Calculate projectile rotation
	setrotation(math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy)))
	-- Draw projectile
	drawimage(cc.HAX.grenade.gfx_wpn,projectiles[id].x,projectiles[id].y)
	-- Draw Arrow if out of Screen
	outofscreenarrow(projectiles[id].x,projectiles[id].y)
end

function cc.HAX.grenade.update(id)
	-- Gravity influence on speed
	projectiles[id].sy=projectiles[id].sy+getgravity()
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/3)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		-- Move X
		projectiles[id].x=projectiles[id].x+msubx
		if collision(col5x5,projectiles[id].x,projectiles[id].y,1,1)==1 then
			if terraincollision()==1 or playercollision()~=projectiles[id].ignore then
				arealdamage(projectiles[id].x,projectiles[id].y,100,50)
				-- Destroy terrain
				terrainexplosion(projectiles[id].x,projectiles[id].y,30,1)
				-- Crater
				grey=math.random(0,40)
				if math.random(0,1)==1 then
					terrainalphaimage(gfx_crater100,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
				else
					terrainalphaimage(gfx_crater125,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
				end
				-- Free projectile
				freeprojectile(id)
				-- Scroll to projectile
				scroll(projectiles[id].x,projectiles[id].y)
			end
		else
			projectiles[id].ignore=0
		end
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			playsound(sfx_hitwater1)
			-- Free projectile
			freeprojectile(id)
			break
		end
	end
	scroll(projectiles[id].x,projectiles[id].y)
	-- Timer -> Explode
	projectiles[id].timer=projectiles[id].timer-1
	if projectiles[id].timer<=0 then
		-- Cause damage
		arealdamage(projectiles[id].x,projectiles[id].y,100,50)
		-- Destroy terrain
		terrainexplosion(projectiles[id].x,projectiles[id].y,30,1)
		-- Crater
		grey=math.random(0,40)
		if math.random(0,1)==1 then
			terrainalphaimage(gfx_crater100,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
		else
			terrainalphaimage(gfx_crater125,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
		end
		-- Free projectile
		freeprojectile(id)
	end
end


